@@ -44,9 +44,6 @@ pub enum Value {
     #[tag("Tokens")]
     Tokens(Tokens),
 
-    #[tag("AtTextValue")]
-    AtText(AtTextValue),
-
     #[tag("Url")]
     Url(Url),
 }
@@ -140,14 +137,6 @@ pub enum BinOp {
     Div,
 }
 
-#[ast_node("AtTextValue")]
-pub struct AtTextValue {
-    pub span: Span,
-    /// Includes `@`.
-    pub name: Ident,
-    pub block: Option<SimpleBlock>,
-}
-
 #[ast_node("Url")]
 pub struct Url {
     pub span: Span,
